---
feature_story: FS_33_76_82_84
feature_title: global tree
feature_status: TODO
---
Keywords: `global_tree`, `gtree`

TODO_26_08_72_06: interp vs delegator: consider making it clear how FT-interp is different (and required to exists) compared to delegator

TODO: This feature will (potentially) combine and replace (or at least affect):
*   FS_01_89_09_24 interp tree (except the FS_42_76_93_51 very first zero arg use case).
*   FS_26_43_73_72 func tree
*   FS_91_88_07_23 jump tree

The idea is that there should be a single tree view (global tree) configuring navigation
instead of distributed across many plugin configs.

